Contributions from everyone, experienced and inexperienced, are welcome!
If you don't know where to start, look at the open [Issues](https://github.com/StingraySoftware/HENDRICS/issues) 
and/or get involved in our [Slack channel ](http://slack-invite.timelabtechnologies.com/).

Please follow the [Astropy contribution guidelines](http://docs.astropy.org/en/stable/development/workflow/development_workflow.html), 
and the [Astropy coding guidelines](http://docs.astropy.org/en/stable/development/codeguide.html#coding-style-conventions). 
This code is written in Python 3.4+, and we strive to be compatible with Python 2.7. 
Tests run at each commit during Pull Requests, so it is easy to single out points in the code that break this compatibility.
